import failWithError from './failWithError';
import IOption from './interfaces/IOption';
import IState from './interfaces/IState';
import parseSpecEntry from './parseSpecEntry';

export default function initState(spec: { [key: string]: IOption }) {
  //The parsed arguments that are returned by this function
  const outputArgs: IState['outputArgs'] = {};

  //Create a lookup table to find a long option when given the short option, and to check if all required options are set
  const shortToLongLookup: IState['shortToLongLookup'] = {};
  const requiredOptions: IState['requiredOptions'] = {};
  try {
    Object.entries(spec).forEach(parseSpecEntry.bind(null, { outputArgs, shortToLongLookup, requiredOptions }));
  } catch (error) {
    failWithError('', (error as Error).message);
  }

  const usage = `./${process.argv[1].substr(process.argv[1].lastIndexOf('/') + 1)} [options]\nOPTIONS\n${
    Object.entries(spec).map(([key, {default: defaultValue, short, description}]) => (
      `  ${(defaultValue === undefined) ? '' : '['}${(short !== undefined && short !== '') ? `-${short}, ` : ''}--${key} <value>${(defaultValue === undefined) ? '' : `], defaults to "${defaultValue}"`}${(description !== undefined && description !== '') ? `\n      ${description}` : ''}`
      )).join('\n')
  }`;

  const failWithUsage: (error?: string) => never = failWithError.bind(null, usage);

  return { outputArgs, shortToLongLookup, requiredOptions, fail: failWithUsage };
}
