/**
 * A command line option
 */
export default interface IOption {
  /** The default value to use, if this argument is missing. If set to `undefined`, this argument is considered to be required and the process will terminate whenever it is missing. */
  default?: string;
  /** The short version option as an alias for the long option, must be a single character. Can be set to an empty string or `undefined` if there should be no short option. */
  short?: string;
  /** A human readable description of this option, for display in the usage message. Not displayed if `undefined` or an empty string. */
  description?: string;
  /** A function that verifies if the given value is a valid value for this option. If set to `undefined`, any value is accepted for this option. */
  verify?: (value: string) => boolean;
  /** A function returning a custom error message that is shown if the verify function returns false. If the function is `undefined`, or it returns `undefined` or an empty string, a default error message is shown instead. */
  message?: (value: string) => string;
}
