/** Runs the given pre-parse hook, if defined, to modify the command line arguments. Returns the modified command line arguments. */
export default function runPreParseHook({ args, preParseHook }: {
  args: string[],
  preParseHook?: (args: string[]) => (string[] | undefined),
}): string[] {
  if (preParseHook === undefined) {
    return args;
  }

  try {
    const modifiedArgs = preParseHook(args);
    return modifiedArgs !== undefined ? modifiedArgs : args;
  } catch (error) {
    throw new Error(`Could not run pre-parse hook, encountered error: ${String(error)}.`);
  }
}
