import IOption from './interfaces/IOption';
import IState from './interfaces/IState';

export default function verifyAndStoreOptionValue({
  option,
  value,
  verify,
  message,
  outputArgs,
  requiredOptions,
}: {
  option: string,
  value: string,
  verify: IOption['verify'],
  message: IOption['message'],
  outputArgs: IState['outputArgs'],
  requiredOptions: IState['requiredOptions'],
}) {
  //Verify value for correctness
  try {
    if (verify !== undefined && !verify(value)) {
      if (message !== undefined) {
        try {
          const customMessage = message(value);
          if (customMessage !== undefined && customMessage !== '') {
            throw new Error(customMessage);
          }
        } catch (error) {
          throw new Error(`Invalid value set for option "${option}": "${value}". Could not show custom error message: ${String(error)}`);
        }
      }
      throw new Error(`Invalid value set for option "${option}": "${value}".`);
    }
  } catch (error) {
    throw new Error(`Invalid value set for option "${option}", the validation of "${value}" failed: ${String(error)}`);
  }

  //Remember the value, and if it is a required argument, mark that we have encountered it
  outputArgs[option] = value;
  if (requiredOptions[option] === false) {
    requiredOptions[option] = true;
  }
}
